@@ -287,6 +287,9 @@ void Qtext_close(Qtext *qtext);
 
 //  application initialization and administration ===============================
 
+int make_appimage_desktop(cchar *appname);                                       //  make appimage desktop and icon files
+void uninstall_appimage();                                                       //  uninstall desktop and icon files
+
 int zinitapp(cchar *appname, cchar *homedir = 0);                                //  initz. app directories and files
 
 cchar * get_zprefix();                                                           //  get /usr or /usr/local  ... 
